if __name__ == '__main__':
    from .util import main
    main()
